#include "mainwidget.h"
#include "ui_mainwidget.h"
#include "intlistmodel.h"
#include <QDebug>

MainWidget::MainWidget(QWidget *parent) :
  QWidget(parent),
  ui(new Ui::MainWidget)
{
  ui->setupUi(this);

  //Создание объекта пользовательской модели
  IntListModel* model = new IntListModel(this);
  //Создание прокси-модели для реализации сортировки элементов
  QSortFilterProxyModel* proxyModel = new QSortFilterProxyModel(this);
  //Назначение модели-источника для прокси-модели
  proxyModel->setSourceModel(model);
  //Назначение прокси-модели для отображения представлениями
  ui->listView->setModel(proxyModel);
  ui->tableView->setModel(proxyModel);

  //Вызов методов, использующих данные модели
  hasElement(22);
  hasElement(100);
  hasElement(435);
}

MainWidget::~MainWidget()
{
  delete ui;
}

void MainWidget::on_btnAsc_clicked()
{
  //Cортировка элементов прокси-модели (не влияет на порядок в модели-источнике)
  ui->listView->model()->sort(0, Qt::AscendingOrder);
}

void MainWidget::on_btnDesc_clicked()
{
  //Cортировка элементов прокси-модели (не влияет на порядок в модели-источнике)
  ui->listView->model()->sort(0, Qt::DescendingOrder);
}

bool MainWidget::hasElement(int value)
{
  QAbstractProxyModel* proxy = (QAbstractProxyModel*)ui->listView->model();
  QAbstractItemModel* model = proxy->sourceModel();

  //Сортировка по возрастанию
  proxy->sort(0);
  qDebug() << "Searching for" << value;

  //Поиск числа среди элементов модели
  for (int i=0; i<model->rowCount(); i++){
    int data = model->data(model->index(i,0)).toInt();
    qDebug() << data;
    if (data == value){
      qDebug() << "Found item" << value;
      return true;
    }
    //Эмуляция случайной сортировки в процессе использования данных модели
    if (i == 1)
      proxy->sort(0, Qt::DescendingOrder); //Сортировка по убыванию
  }
  qDebug() << "Item" << value << "not found";
  return false;
}
